/*
#ident	"@(#)smail/compat:RELEASE-3_2_0_115:dummy.c,v 1.5 2003/03/27 16:34:13 woods Exp"
 */

#include "defs.h"
#include <sys/types.h>
#include "../src/smail.h"
#include "compat.h"
#include "../src/smailport.h"

/*
 * Provide a dummy reference so there is at least one item in
 * compat.a.  This will keep ld from complaining about empty libraries
 * and such.
 */
int
dummy_reference()
{
    return 1;
}
